==> zio-aws-databasemigration_2.12-6.20.78.1-sources.jar: zio/aws/databasemigration/model/CreateEndpointResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateEndpointResponse(
    endpoint: Optional[zio.aws.databasemigration.model.Endpoint] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse = {
    import CreateEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse
      .builder()
      .optionallyWith(endpoint.map(value => value.buildAwsValue()))(_.endpoint)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.CreateEndpointResponse.ReadOnly =
    zio.aws.databasemigration.model.CreateEndpointResponse.wrap(buildAwsValue())
}
object CreateEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databasemigration.model.CreateEndpointResponse =
      zio.aws.databasemigration.model
        .CreateEndpointResponse(endpoint.map(value => value.asEditable))
    def endpoint: Optional[zio.aws.databasemigration.model.Endpoint.ReadOnly]
    def getEndpoint: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.Endpoint.ReadOnly
    ] = AwsError.unwrapOptionField("endpoint", endpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse
  ) extends zio.aws.databasemigration.model.CreateEndpointResponse.ReadOnly {
    override val endpoint
        : Optional[zio.aws.databasemigration.model.Endpoint.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.endpoint())
        .map(value => zio.aws.databasemigration.model.Endpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse
  ): zio.aws.databasemigration.model.CreateEndpointResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-databasemigration_2.13-5.17.124.3-sources.jar: zio/aws/databasemigration/model/CreateEndpointResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateEndpointResponse(
    endpoint: Option[zio.aws.databasemigration.model.Endpoint] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse = {
    import CreateEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse
      .builder()
      .optionallyWith(endpoint.map(value => value.buildAwsValue()))(_.endpoint)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.CreateEndpointResponse.ReadOnly =
    zio.aws.databasemigration.model.CreateEndpointResponse.wrap(buildAwsValue())
}
object CreateEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databasemigration.model.CreateEndpointResponse =
      zio.aws.databasemigration.model
        .CreateEndpointResponse(endpoint.map(value => value.asEditable))
    def endpoint: Option[zio.aws.databasemigration.model.Endpoint.ReadOnly]
    def getEndpoint: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.Endpoint.ReadOnly
    ] = AwsError.unwrapOptionField("endpoint", endpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse
  ) extends zio.aws.databasemigration.model.CreateEndpointResponse.ReadOnly {
    override val endpoint
        : Option[zio.aws.databasemigration.model.Endpoint.ReadOnly] = scala
      .Option(impl.endpoint())
      .map(value => zio.aws.databasemigration.model.Endpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.CreateEndpointResponse
  ): zio.aws.databasemigration.model.CreateEndpointResponse.ReadOnly =
    new Wrapper(impl)
}
